@@ -15,6 +15,7 @@ Support for vault files.
 """
 
 from __future__ import absolute_import, print_function
+import os
 from copy import deepcopy
 import jsonschema
 import easy_vault
@@ -145,8 +146,8 @@ class VaultFile(object):
           VaultFileDecryptError: Error with decrypting the vault file
           VaultFileFormatError: Invalid vault file format
         """
-        self._filepath = filepath
-        self._vault_obj = _load_vault_file(
+        self._filepath = os.path.abspath(filepath)
+        self._vault_obj, self._encrypted = _load_vault_file(
             filepath, password, use_keyring, use_prompting, verbose)
 
         # The following attributes are for faster access
@@ -166,6 +167,15 @@ class VaultFile(object):
         """
         return list(self._secrets.keys())
 
+    def is_encrypted(self):
+        """
+        Return whether the vault file is encrypted.
+
+        Returns:
+          bool: Boolean indicating whether the vault file is encrypted.
+        """
+        return self._encrypted
+
     def get_secrets(self, nickname):
         """
         Get the secrets item from the vault file for a given server nickname.
@@ -214,7 +224,8 @@ class VaultFile(object):
 
 def _load_vault_file(filepath, password, use_keyring, use_prompting, verbose):
     """
-    Load the vault file and return its complete content.
+    Load the vault file and return its complete content and whether it is
+    encrypted.
 
     The format of the vault file is validated against a JSON schema.
 
@@ -239,7 +250,9 @@ def _load_vault_file(filepath, password, use_keyring, use_prompting, verbose):
         is displayed regardless of verbose mode.
 
     Returns:
-      dict: Python dict representing the vault file content.
+      tuple(dict, bool): Tuple of:
+      * dict: Python dict representing the vault file content.
+      * bool: Indicates wether the vault file is encrypted.
 
     Raises:
       VaultFileOpenError: Error with opening the vault file
@@ -247,7 +260,14 @@ def _load_vault_file(filepath, password, use_keyring, use_prompting, verbose):
       VaultFileFormatError: Invalid vault file format
     """
 
-    if password is None and easy_vault.EasyVault(filepath).is_encrypted():
+    try:
+        encrypted = easy_vault.EasyVault(filepath).is_encrypted()
+    except easy_vault.EasyVaultFileError as exc:
+        new_exc = VaultFileOpenError(str(exc))
+        new_exc.__cause__ = None
+        raise new_exc  # VaultFileOpenError
+
+    if password is None and encrypted:
         password = easy_vault.get_password(
             filepath, use_keyring=use_keyring, use_prompting=use_prompting,
             verbose=verbose)
@@ -289,4 +309,4 @@ def _load_vault_file(filepath, password, use_keyring, use_prompting, verbose):
         new_exc.__cause__ = None
         raise new_exc  # VaultFileFormatError
 
-    return vault_obj
+    return vault_obj, encrypted
